"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fluentLogger = require("fluent-logger");
var winston = require("winston");
var fluentTransport = fluentLogger.support.winstonTransport();
exports.DEFAULT_ID = 'instance';
exports.DEFAULT_LEVELS = {
    silly: 5000,
    debug: 4000,
    info: 3000,
    http: 2000,
    warn: 1000,
    error: 0,
};
exports.DEFAULT_LEVEL = 'info';
exports.logger = {
    count: 0,
    createConsoleTransport: createConsoleTransport,
    createFluentTransport: createFluentTransport,
    createZipkinContextFormatter: createZipkinContextFormatter,
    initialize: initialize,
    use: use,
    _instances: {},
};
function use(id) {
    if (!exports.logger._instances[id]) {
        // tslint:disable-next-line max-line-length
        throw new Error("No logger with ID \"" + id + "\" could be found. Have you initialised it?");
    }
    return exports.logger._instances[id];
}
exports.use = use;
function createConsoleTransport() {
    return new winston.transports.Console();
}
exports.createConsoleTransport = createConsoleTransport;
var DEFAULT_FLUENT_ID = 'fluent';
var DEFAULT_FLUENT_HOST = 'localhost';
var DEFAULT_FLUENT_PORT = 24224;
var DEFAULT_FLUENT_REQUIRE_ACK_RESPONSE = false;
var DEFAULT_FLUENT_SECURITY = {};
var DEFAULT_FLUENT_TIMEOUT = 3.0;
var DEFAULT_FLUENT_TLS = false;
var DEFAULT_FLUENT_TLS_OPTIONS = {};
function createFluentTransport(_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.id, id = _c === void 0 ? DEFAULT_FLUENT_ID : _c, _d = _b.host, host = _d === void 0 ? DEFAULT_FLUENT_HOST : _d, _e = _b.port, port = _e === void 0 ? DEFAULT_FLUENT_PORT : _e, _f = _b.requireAckResponse, requireAckResponse = _f === void 0 ? DEFAULT_FLUENT_REQUIRE_ACK_RESPONSE : _f, _g = _b.security, security = _g === void 0 ? DEFAULT_FLUENT_SECURITY : _g, _h = _b.timeout, timeout = _h === void 0 ? DEFAULT_FLUENT_TIMEOUT : _h, _j = _b.tls, tls = _j === void 0 ? DEFAULT_FLUENT_TLS : _j, _k = _b.tlsOptions, tlsOptions = _k === void 0 ? DEFAULT_FLUENT_TLS_OPTIONS : _k;
    return new fluentTransport({
        host: host,
        port: port,
        requireAckResponse: requireAckResponse,
        security: security,
        tag: id,
        timeout: timeout,
        tls: tls,
        tlsOptions: tlsOptions,
    });
}
exports.createFluentTransport = createFluentTransport;
function createZipkinContextFormatter(_a) {
    var loggerId = _a.loggerId, context = _a.context;
    return function (info) {
        info.loggerId = loggerId;
        if (context.currentCtx !== null) {
            info.spanId = context.currentCtx.spanId;
            info.traceId = context.currentCtx.traceId;
            info.parentId = context.currentCtx.parentId;
            info.sampled = context.currentCtx.sampled;
        }
        return info;
    };
}
exports.createZipkinContextFormatter = createZipkinContextFormatter;
function initialize(_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.id, id = _c === void 0 ? exports.DEFAULT_ID : _c, _d = _b.formats, formats = _d === void 0 ? [] : _d, _e = _b.levels, levels = _e === void 0 ? exports.DEFAULT_LEVELS : _e, _f = _b.level, level = _f === void 0 ? exports.DEFAULT_LEVEL : _f, _g = _b.plugins, plugins = _g === void 0 ? [] : _g, _h = _b.setPrimary, setPrimary = _h === void 0 ? false : _h, _j = _b.transports, transports = _j === void 0 ? [] : _j;
    var _k;
    if (exports.logger._instances[id]) {
        // tslint:disable-next-line max-line-length
        throw new Error("The logger's id, \"" + id + "\", clashes with an existing logger.");
    }
    else {
        var pluginFormatters = plugins.map(function (plugin) { return winston.format(plugin.format); });
        var additionalFormatters = formats.map(function (additionalFormatter) { return winston.format(additionalFormatter); });
        var baseFormatters = [winston.format.timestamp, winston.format.json];
        var format = (_k = winston.format).combine.apply(_k, additionalFormatters.map(function (v) { return v(); }).concat(pluginFormatters.map(function (v) { return v(); }), baseFormatters.map(function (v) { return v(); })));
        var pluginTransporters = plugins.map(function (plugin) { return plugin.transport; });
        var baseTransporters = transports;
        var transporters = pluginTransporters.concat(baseTransporters);
        exports.logger._instances[id] = winston.createLogger({
            exitOnError: false,
            format: format,
            level: level,
            levels: levels,
            transports: transporters,
        });
    }
    if (exports.logger.count++ === 0 || setPrimary === true) {
        Object.keys(levels)
            .forEach(function (levelKey) {
            return exports.logger[levelKey] = exports.logger._instances[id][levelKey];
        });
    }
}
//# sourceMappingURL=index.js.map